#ifndef _main_h_
#define _main_h_
#include <avr\interrupt.h>
#include <avr\io.h>
#include "mydefs.h"


#ifndef F_CPU
/* In neueren Version der WinAVR/Mfile Makefile-Vorlage kann
   F_CPU im Makefile definiert werden, eine nochmalige Definition
   hier wuerde zu einer Compilerwarnung fuehren. Daher "Schutz" durch
   #ifndef/#endif 
 
   Dieser "Schutz" kann zu Debugsessions fhren, wenn AVRStudio 
   verwendet wird und dort eine andere, nicht zur Hardware passende 
   Taktrate eingestellt ist: Dann wird die folgende Definition 
   nicht verwendet, sondern stattdessen der Defaultwert (8 MHz?) 
   von AVRStudio - daher Ausgabe einer Warnung falls F_CPU
   noch nicht definiert: */
	#error "F_CPU ist noch nicht definiert"
#endif

//define BAUD 115200UL      // Baudrate
#define BAUD 230400UL      // Baudrate
//#define BAUD 256000UL      // Baudrate

// Berechnungen
#define UBRR_VAL ((F_CPU+BAUD*8)/(BAUD*16)-1)   // clever runden
#define BAUD_REAL (F_CPU/(16*(UBRR_VAL+1)))     // Reale Baudrate
#define BAUD_ERROR ((BAUD_REAL*1000)/BAUD) 		// Fehler in Promille, 1000 = kein Fehler.
 
#if ((BAUD_ERROR<990) || (BAUD_ERROR>1010))
  #error Systematischer Fehler der Baudrate grsser 1% und damit zu hoch! 
#endif

#define	LINEFEED	"\n"


#define	SCL			SBIT( PORTB, 7 )
#define SCL_DDR		SBIT( DDRB, 7 )
#define	SCL_PIN		SBIT( PINB, 7 )

#define	SDA			SBIT( PORTB, 5 )
#define	SDA_DDR		SBIT( DDRB, 5 )
#define	SDA_PIN		SBIT( PINB, 5 )

#endif
